/*
 * Enhydra Java Application Server Project
 *
 * The contents of this file are subject to the Enhydra Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License on
 * the Enhydra web site ( http://www.enhydra.org/ ).
 *
 * Software distributed under the License is distributed on an "AS IS"
 * basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
 * the License for the specific terms governing rights and limitations
 * under the License.
 *
 * The Initial Developer of the Enhydra Application Server is Lutris
 * Technologies, Inc. The Enhydra Application Server and portions created
 * by Lutris Technologies, Inc. are Copyright Lutris Technologies, Inc.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 */
package kelp.webapp.presentation;

// Xerces imports
import org.w3c.dom.Node;
import org.w3c.dom.html.HTMLElement;

// Servlet imports
import javax.servlet.ServletException;
import javax.servlet.ServletOutputStream;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

// Standard imports
import java.io.BufferedReader;
import java.io.ByteArrayInputStream;
import java.io.IOException;
import java.io.File;
import java.io.FileInputStream;
import java.io.InputStreamReader;

/**
 * <p>
 * This presentation object dynamically creates an HTML page
 * showing the greeting from the application configuration file.
 * </p>
 */
public class NewNodeServlet extends HttpServlet {
    public void doGet(HttpServletRequest request,
                      HttpServletResponse response) throws ServletException,
                      IOException {
        NewNodeHTML page = null;
        ServletOutputStream out;
        byte[] buffer;

        page = createPage();
        buffer = page.toDocument().getBytes();
        response.setContentType( "text/html" );
        response.setContentLength( buffer.length );
        out = response.getOutputStream();
        out.write(buffer);
        out.flush();
        response.flushBuffer();
    }

    public NewNodeHTML createPage() {
        NewNodeHTML page = null;
        HTMLElement element = null;
        Node        newNode = null;
        String      fileContent = null;

        page = new NewNodeHTML();
        fileContent = readFile();
        newNode = page.createCDATASection(fileContent);
        element = page.getElementSpanInsertHere();
        element.getParentNode().replaceChild(newNode, element);
        return page;
    }

    private String readFile() {
        File                 nodeFile = null;
        FileInputStream      fileStream = null;
        InputStreamReader    inReader = null;
        BufferedReader       buffer = null;
        ByteArrayInputStream byteIn = null;
        String               inLine = null;
        StringBuffer         outBuf = new StringBuffer();
        StringBuffer         pathBuf = new StringBuffer();

        pathBuf.append(getInitParameter("testDataPath"));
        if (pathBuf.length() == 0) {
            outBuf.append("<p>init-parm not found: testDataPath</p>");
        } else {

            // Remove quotes
            int lastAt = -1;

            lastAt = pathBuf.length() - 1;
            if (pathBuf.charAt(lastAt) == '"') {
                pathBuf.deleteCharAt(lastAt);
            }
            if (pathBuf.charAt(0) == '"') {
                pathBuf.deleteCharAt(0);
            }
            pathBuf.append('/');
            pathBuf.append("newnode.txt");
            try {
                nodeFile = new File(pathBuf.toString());
                fileStream = new FileInputStream(nodeFile);
                inReader = new InputStreamReader(fileStream);
                buffer = new BufferedReader(inReader);
                inLine = new String();
                while (inLine != null) {
                    inLine = buffer.readLine();
                    if (inLine != null) {
                        outBuf.append(inLine);
                    }
                }
                buffer.close();
                inReader.close();
                fileStream.close();
            } catch (IOException e) {
                outBuf.append(e.getMessage());
            }
        }
        return outBuf.toString();
    }

}
